/* This is -*- C -*- */
/* $Id: jitter.h,v 1.2 2000/02/06 03:17:13 trow Exp $ */

/*
 * jitter.h
 *
 * Copyright (C) 1999, 2000 EMC Capital Management, Inc.
 *
 * Developed by Jon Trowbridge <trow@gnu.org>
 * and Havoc Pennington <hp@pobox.com>.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 * USA
 */

#ifndef _INC_JITTER_H
#define _INC_JITTER_H

#include <config.h>
#include <gnome.h>

/* Return "quasi-random" (x,y) values s.t. |(x,y)| <= 1 */
void jitter(guint seed, double size, gint i, double* xj, double* yj);


#endif /* _INC_JITTER_H */

/* $Id: jitter.h,v 1.2 2000/02/06 03:17:13 trow Exp $ */
